Computer controlled cutting
===========================

This week I worked on designing parametrically for laser cutting. Also, tried out cutting small things on the vinyl cutter.

Laser cutting
-------------

### Designing the construction kit

I sketched out a simple module so all dimensions were a multiple of the either the:

1.  Thickness of material
2.  Kerf

I wanted to keep the module itself simple so that it would:

*   Use less material
*   Provide multiple ways of assembly


So I sketched out frame modules with notches at the ends for connections.


![module idea sketch](./images/ccc/sketch.jpg)

### The script

After various attempts in rhino+grasshopper and fusion360, I found a tutorial on notching. I tried that out, modified it to work for my module idea, and then ended up with a file where you could modify:

1.  Thickness of Material
2.  Kerf of laser
3.  Number of arms on the module
4.  Type of notch - press-fit, chamfer, or snap-fit

You can find the script at the bottom of this page.

Some attempted scripts that didn't work as a whole:

![](./images/ccc/1.jpg)  

![](./images/ccc/2.jpg)  

![](./images/ccc/3.jpg)  

![](./images/ccc/4.jpg)  


### The machine

We could use one of [three laser cutters at FabLabBCN](https://fablabbcn.org/machines.html). I started with the smallest Trotec Speedy 100 this week. It has a bed size of 610mm x 305mm and power of 12-60W. It is good for cutting paper, cardboard, MDF, plywood, acrylic.

### Material dimensions

First I cut out a ply of 300mm by 600mm out of a big sheet. Using a vernier calliper I measured the thickness of the material in several places.  
![Material thickness: 4.35 mm](./images/ccc/material.jpg)

### Setting focus

The focus of the machine can be set by adjusting the distance of the Z axis of the bed from the material's top surface. We have a small probe at the lab, an attachment that you hang on the side of the laser nozzle. You manually move the bed up and when the probe touches the material, it falls off. This position sets the z-axis of the machine.  
![gif of probe falling](./images/ccc/focus.gif)

### Measuring kerf

First, I cut a small square of 20mm x 20mm to check:

1.  Power and speed settings - I used the cutting guide to set the power to 75% and speed to 0.5mm/s for cutting.
2.  Kerf - After measuring the outside dimension of the square itself and the inside dimension of the negative left in the sheet, I divided the difference by 2 and found the kerf of the machine to be 0.15mm.

![](./images/ccc/inside.jpg)  

![](./images/ccc/outside.jpg)  

![](./images/ccc/difference.jpg)  


### Add to parametric file

Now that I had found my 2 parameters : thickness=4.35mm and kerf=0.15mm, I adjusted the sliders on my gh script.  
![Parameters](./images/ccc/parameters.jpg)

### Bake model

I tried multiple different combinations of the number of module arms, and the type of notches to test everything and baked them separately. I adjusted them manually in Rhino to fit inside 300mm by 600mm. I put them in a the same layer in black for cutting.  
Here is the Rhino file.  
![various modules](./images/ccc/modules.jpg)

### Set cutting parameters

Checked for no duplicate and all flat lines, and set material parameters.

![settings](./images/ccc/settings.jpg)  


### Assembly

The pieces came out neat using the cutting settings. ![](./images/ccc/pieces.jpg)  
Some different assemblies:  
![](./images/ccc/assembly1.jpg)  

![](./images/ccc/assembly2.jpg)  

![](./images/ccc/assembly3.jpg)  


### For next time:

1.  Cut inside parts first, because the piece shifted when it cut the outside first. Put them in a separate layer.
2.  Since ply is a little warped - put the material concave side up to allow sticking the edges to the bed.  
    ![](./images/ccc/warped.jpg)
3.  Lots of material wasted in the sheet - use nesting software/plug-in to optimise curves.  
    ![](./images/ccc/waste.jpg)
4.  Modules too big and long - modify some multiples of thickness in script and make them shorter.
5.  The snapping part of the snap-fit notch was too small (equal to the kerf) - modify the script to make it bigger.  
    ![](./images/ccc/snap.jpg)

### Design Files

Final files: [The rhino notch file](./images/ccc/notch.rhino.zip) used with this [grasshopper script](./images/ccc/parametric.modules.gh.zip)

[All failed Fusion files](../fabacademy/images/week2/fusion.zip)  
[All grasshopper script attemps](./images/ccc/gh.zip)

Vinyl cutting
-------------

I used a Roland Camm-1 in our lab to cut some white vinyl stickers.

![](./images/ccc/machine.jpg)

### Designing a vector sketched

I made two sketches, one an axonometric cube stack and the other a some letters. I cut some simple curves that I made on Adobe Illustrator. I made them with the line tool. Gave some thickness to the lines. Made path outlines and then did a boolean union on pathfinder tools to make single outlines. The figure on the left is outlines, the one on the right is just paths. ![](./images/ccc/designing.jpg)

### Testing and setting Parameters

After loading the material as a roll, I used these settings:  
Speed: 5cm/s  
Force: 180 gf  
Depth: 0.250mm

![](./images/ccc/setting.jpg)

I tried the first test cut and it came out perfectly. The circle outside the inner square came out perfectly without cutting through the backing.

![](./images/ccc/test.jpg)

### Loading file and cutting

So I loaded my design file and used the ai Roland plug-in to cut. The cutting was quite fast. Here is a picture of the vinyl still loaded: ![](./images/ccc/cutting.jpg)

### Peeling Vinyl

After finishing, I unloaded the vinyl and cut out the parts separately. ![](./images/ccc/cut.jpg)

I then used a nose-end tweezer and started to remove all the negative parts. It actually took some time, as they were as thin and intertwined with the positives. Here are some pictures of that process: ![](./images/ccc/peel1.jpg)  
![](./images/ccc/peel2.jpg)

And this is how it looks like: ![](./images/ccc/peel3.jpg)

I haven't yet applied to any surface, but I will have to do this step carefully, as the parts are quite thin.

### Design files

[AI file](./images/ccc/vinylcutter.ai.zip)
